@@ -17,8 +17,6 @@ BEGIN {
 	);
 }
 
-use CGI::Search::Config;  # System-specific configuration info
-
 
 
 =head1 NAME
@@ -53,17 +51,24 @@ CGI::Search - Simple way of using a CGI to search flat-text database files.
 	[ 'field1', $CUSTOM_VALIDATOR,  0  ], 
   );
 
-  # Paging options (not currently supported).  All are automatically verfied as an INTEGER
+  # Paging options.  All are automatically verfied as an INTEGER
   my $RESULTS_PER_PAGE = param('RESULTS_PER_PAGE') || 0;
   my $MAX_RESULTS      = 0;  # Infinate
   my $PAGE_NUMBER      = param('PAGE') || 0;
   
   # Search options
-  my %SEARCH           = (
+  my %SEARCH = (
   	num1   => [ param("num1"),  \&INTEGER ], 
 	email  => [ param("email"), \&EMAIL   ], 
   );
 
+  # Other fields.  These are passed to your script when pagination occurs, 
+  # but are not involved in the search
+  my %OTHER = (
+  	param1  => param('param1') || 0, 
+	param2  => param('param2') || 0, 
+  );
+
   
   my $search = CGI::Search->new(
   	script_name       => $ENV{SCRIPT_NAME}, 
@@ -75,6 +80,7 @@ CGI::Search - Simple way of using a CGI to search flat-text database files.
 	max_results       => $MAX_RESULTS, 
 	page_number       => $PAGE_NUMBER, 
 	search_fields     => \%SEARCH, 
+	other             => \%OTHER, 
   );
 
   # List context   -- return array-of-hashes
@@ -297,8 +303,11 @@ Constructor.  Takes the following options in the hash:
   # Search options
   search_fields     Referance to a hash of arrays describing the fields you need to search on.  
                     See SEARCH FIELDS.
+  other             These are paramters that are passed into your script, but they aren't 
+                    involved in the search itself.  These will be added to the input fields 
+		    that show up when you use pagination.
 
-  # Paging options (not currently implemented)
+  # Paging options
   results_per_page  How many results to show on each page of output.  Default is 0 (infinte).
   max_results       Maximum number of results to search for.  Default is 0 (infinite).
   page_number       The current page number of output.  Default is 0 (first page).
@@ -335,13 +344,13 @@ override the terms passed to new().
 
   get_prev_page
 
-Returns the page number of the previous page or undef if we're on the first page.
+Returns true if there should be a previous page.
 
 =head2 get_next_page
 
   get_next_page
 
-Returns the page number of the next page.  Note that CGI::Search doesn't know if there 
+Returns true if there should be a next page. Note that CGI::Search doesn't know if there 
 will be any results on the "next" page, so this will happily return a value for page 
 249 if a user clicks that much, even if the results stoped at page 7.
 
@@ -363,8 +372,6 @@ Yes.
 
 =head1 TODO
 
-Add pagination support.
-
 Reimplement INTEGER() using Regexp::Common::number (other validators, too?).
 
 Using an SQL-like syntax to do searching instead of a hash of options (???)
@@ -599,6 +606,13 @@ my $result_template = sub
 			);
 			push @search_fields, \%field;
 		}
+		foreach my $i (keys %{ $self->{other} }) {
+			my %field = (
+				name  => $i, 
+				value => $self->{other}{$i}, 
+			);
+			push @search_fields, \%field;
+		}
 
 		$tmpl->param(search_fields    => \@search_fields);
 		$tmpl->param(results_per_page => $self->{results_per_page});
@@ -728,6 +742,7 @@ sub new
 	$self->{db_seperator}     = defined($input{db_seperator}) ? $input{db_seperator} : '\|'; 
 	$self->{db_fields}        = $input{db_fields}         || undef; 
 	$self->{search_fields}    = $input{search_fields}     || undef; 
+	$self->{other}            = $input{other}             || undef;
 
 	$self->{results_per_page} = $input{results_per_page}  || 0;
 	$self->{max_results}      = $input{max_results}       || 0;
